@@ -60,6 +60,7 @@ function display_result(&$tag) {
     global $logfacility;
     global $db_types;
     global $str_code;
+    global $web_conf; 
 
     /* ѥ */
     $commandpass = "";
@@ -163,6 +164,15 @@ function display_result(&$tag) {
     }
     $tag["<<TEMPLATEPATH>>"] = $templatepath;
 
+
+    /* Υ᡼ƥץ졼ȥѥ */
+    $rcpttemplatepath = "";
+    if (isset($samma_conf["rcpttemplatepath"]) === TRUE &&
+              $samma_conf["rcpttemplatepath"] != "") {
+        $rcpttemplatepath = escape_html($samma_conf["rcpttemplatepath"]);
+    }
+    $tag["<<RCPTTEMPLATEPATH>>"] = $rcpttemplatepath;
+
     /* sendmailޥɥѥ/ץ */
     $sendmailcommand = "";
     if (isset($samma_conf["sendmailcommand"]) === TRUE && 
@@ -322,6 +332,120 @@ function display_result(&$tag) {
     }
     $tag["<<E_FILE>>"] = $e_file;
 
+
+    /* ˥ѥ */
+    $passnotice_disabled = "disabled";
+    $passnotice_sender = "";
+    $passnotice_rcpt = "";
+    $passnotice_both = "";
+    
+    /* ˥ѥεǽͭˤʤäƤ */
+    if (is_active_plugin("pluginpassnoticeactive")) {
+
+        $passnotice_disabled = "";
+ 
+        /* passwordnoticeܤåȤƤ */
+        if (isset($samma_conf["passwordnotice"])) {
+            if ($samma_conf["passwordnotice"] == "0") {
+                $passnotice_sender = "checked";
+            } elseif ($samma_conf["passwordnotice"] == "1") {
+                $passnotice_rcpt = "checked";
+            } elseif ($samma_conf["passwordnotice"] == "2") {
+                $passnotice_both = "checked";
+            } else {
+                $passnotice_sender = "checked";
+            }
+        } else {
+            $passnotice_sender = "checked";
+        }
+    }
+
+    $tag["<<PLUGINPASSNOTICEACTIVE>>"] = $passnotice_disabled;
+    $tag["<<PASSNOTICE_SENDER>>"] = $passnotice_sender;
+    $tag["<<PASSNOTICE_RCPT>>"] = $passnotice_rcpt;
+    $tag["<<PASSNOTICE_BOTH>>"] = $passnotice_both;
+
+    /* subjectswɲõǽ */
+    $output_pass_log = "Ϥʤ";
+    $subjectsw_disable = "disabled";
+    $useaddmessageheader_on = "";
+    $useaddmessageheader_off = "checked";
+    $messagetmpljppath = "";
+    $messagetmplenpath = "";
+    $messagetmplbothpath = "";
+    $useencryptsubject_on = "";
+    $useencryptsubject_off = "checked";
+    $subjectencryptstringjp = "";
+    $subjectencryptstringen = "";
+
+    /* subjectswɲõǽͭˤʤäƤ */
+    if (is_active_plugin("pluginsubjectswactive")) {
+
+        $output_pass_log = "Ϥ";
+        $subjectsw_disable = "";
+ 
+        /* ᡼ʸ귿ʸ */
+        if (isset($samma_conf["useaddmessageheader"])) {
+            if ($samma_conf["useaddmessageheader"] === "yes") {
+                $useaddmessageheader_on = "checked";
+                $useaddmessageheader_off = "";
+            }
+        }
+
+        /* ʸɵΥեѥ(ܸ) */
+        if (isset($samma_conf["messagetmpljppath"])) {
+            $messagetmpljppath = escape_html($samma_conf["messagetmpljppath"]);
+        }
+
+        /* ʸɵΥեѥ(Ѹ) */
+        if (isset($samma_conf["messagetmplenpath"])) {
+            $messagetmplenpath = escape_html($samma_conf["messagetmplenpath"]);
+        }
+
+        /* ʸɵΥեѥ(ξ) */
+        if (isset($samma_conf["messagetmplbothpath"])) {
+            $messagetmplbothpath = escape_html($samma_conf["messagetmplbothpath"]);
+        }
+
+        /* ̾ȽŹ沽 */
+        if (isset($samma_conf["useencryptsubject"])) {
+            if ($samma_conf["useencryptsubject"] === "yes") {
+                $useencryptsubject_on = "checked";
+                $useencryptsubject_off = "";
+            }
+        }
+
+        /* ̾Ƚʸ(ܸ) */
+        if (isset($samma_conf["subjectencryptstringjp"])) {
+            $subjectencryptstringjp = escape_html($samma_conf["subjectencryptstringjp"]);
+        }
+
+        /* ̾Ƚʸ(Ѹ) */
+        if (isset($samma_conf["subjectencryptstringen"])) {
+            $subjectencryptstringen = escape_html($samma_conf["subjectencryptstringen"]);
+        }
+    }
+
+    $tag["<<PLUGINSUBJECTSWACTIVE>>"] = $subjectsw_disable;
+    $tag["<<OUTPUTPASSTOLOG>>"] = $output_pass_log;
+    $tag["<<USERADDMESSAGEHEADER_ON>>"] = $useaddmessageheader_on;
+    $tag["<<USERADDMESSAGEHEADER_OFF>>"] = $useaddmessageheader_off;
+    $tag["<<MESSAGETMPLJPPATH>>"] = $messagetmpljppath;
+    $tag["<<MESSAGETMPLENPATH>>"] = $messagetmplenpath;
+    $tag["<<MESSAGETMPLBOTHPATH>>"] = $messagetmplbothpath;
+    $tag["<<USERENCRYPTSUBJECT_ON>>"] = $useencryptsubject_on;
+    $tag["<<USERENCRYPTSUBJECT_OFF>>"] = $useencryptsubject_off;
+    $tag["<<SUBJECTENCRYPTSTRINGJP>>"] = $subjectencryptstringjp;
+    $tag["<<SUBJECTENCRYPTSTRINGEND>>"] = $subjectencryptstringen;
+
+    /* źեեContent-Type */
+    $zipattachmentcontenttype = "";
+    if (isset($samma_conf["zipattachmentcontenttype"]) === TRUE &&
+              $samma_conf["zipattachmentcontenttype"] != "") {
+        $zipattachmentcontenttype = escape_html($samma_conf["zipattachmentcontenttype"]);
+    }
+    $tag["<<ZIP_ATTCHMENT_CONTENT_TYPE>>"] = $zipattachmentcontenttype;
+    
     return TRUE;
 }
 
@@ -381,7 +505,7 @@ function check_conf_data(&$data)
     /* zipޥɥѥ */
     /* å */
     if ($data["zipcommand"] == "") {
-        $err_msg = "zipޥɥѥϤƤޤ";
+        $err_msg = "ޥɥѥϤƤޤ";
         return FALSE;
     }
     /* å*/
@@ -396,7 +520,7 @@ function check_conf_data(&$data)
     if ($data["zipcommandopt"] != "") {
         /* å*/
         if (check_str($data["zipcommandopt"], CHECK_STR4) !== TRUE) {
-            $err_msg = "zipޥɥץ" . $err_msg;
+            $err_msg = "ޥɥץ" . $err_msg;
             return FALSE;
         }
     }
@@ -445,10 +569,17 @@ function check_conf_data(&$data)
         return FALSE;
     }
     /* å(ʤк) */
-    if (check_tmpl($data["templatepath"]) === FALSE) {
+    if (check_tmpl($data["templatepath"], DEF_TMPL) === FALSE) {
         return FALSE;
     }
 
+    /* ƥץ졼 */
+    if ($data["rcpttemplatepath"] !== "") {
+        /* å(ʤк) */
+        if (check_tmpl($data["rcpttemplatepath"], DEF_RCPT_TMPL) === FALSE) {
+            return FALSE;
+        }
+    }
 
     /* sendmailޥɥѥ/ץ */
     /* å */
@@ -472,12 +603,12 @@ function check_conf_data(&$data)
     /* Ź沽ZIPեեޥå */
     /* å */
     if ($data["zipfilename"] == "") {
-        $err_msg = "Ź沽ZIPեեޥåȤϤƤޤ";
+        $err_msg = "ԤϤ᡼źեե̾եޥåȤϤƤޤ";
         return FALSE;
     }
     /* å*/
     if (check_str($data["zipfilename"], CHECK_STR3) !== TRUE) {
-        $err_msg = "zipޥɥץ" . $err_msg;
+        $err_msg = "ޥɥץ" . $err_msg;
         return FALSE;
     }
 
@@ -560,7 +691,7 @@ function check_conf_data(&$data)
             return FALSE;
         }
         /* å*/
-        if (check_str($data["ldapbasedn"], CHECK_STR3) !== TRUE) {
+        if (check_str($data["ldapbasedn"], CHECK_STR6) !== TRUE) {
             $err_msg = "LDAP١DN" . $err_msg;
             return FALSE;
         }
@@ -573,7 +704,7 @@ function check_conf_data(&$data)
             return FALSE;
         }
         /* å*/
-        if (check_str($data["ldapbinddn"], CHECK_STR3) !== TRUE) {
+        if (check_str($data["ldapbinddn"], CHECK_STR6) !== TRUE) {
             $err_msg = "LDAPХDN" . $err_msg;
             return FALSE;
         }
@@ -623,8 +754,150 @@ function check_conf_data(&$data)
         }
     }
 
-    return TRUE;
+    /* ˥ѥɤΤ뵡ǽͭˤʤäƤ */
+    if (is_active_plugin("pluginpassnoticeactive")) {
+        /* ѥΤ */
+        if ($data["passwordnotice"] !== "0" && 
+            $data["passwordnotice"] !== "1" && 
+            $data["passwordnotice"] !== "2") {
+            $err_msg = "ѥΤ꤬Ǥ(" . $data['passwordnotice']. ")";
+            return FALSE;
+         }
+    }
 
+    /* subjectswǽͭˤʤäƤ */
+    if (is_active_plugin("pluginsubjectswactive")) {
+
+        /* ᡼ʸ귿ʸ */
+        if (($data["useaddmessageheader"] != "yes") && ($data["useaddmessageheader"] != "no")) {
+            $err_msg = "᡼ʸ귿ʸ꤬Ǥ(" . $data["useaddmessageheader"] . ")";
+            return FALSE;
+        }
+
+        /* ʸɵΥեѥ */
+        $ret = check_messagetmplpath($data["messagetmpljppath"], 
+                                     $data["messagetmplenpath"],
+                                     $data["messagetmplbothpath"], $errormsg);
+        if (!$ret) {
+            $err_msg = $errormsg;
+            return FALSE;
+        }
+
+        /* ̾ȽŹ沽 */
+        if (($data["useencryptsubject"] != "yes") && ($data["useencryptsubject"] != "no")) {
+            $err_msg = "̾Ƚ꤬Ǥ(". $data["useencryptsubject"]. ")";
+            return FALSE;
+        }
+
+        /* ̾Ƚʸ(ܸ) */
+        $ret = check_str($data["subjectencryptstringjp"], "[]{}()@!#$%&+*=-/:;.,?_", 0, 256);
+        if (!$ret) {
+            $err_msg = "̾Ƚʸ(ܸ)ηǤ(". $data["subjectencryptstringjp"]. ")";
+            return FALSE;
+        } 
+
+        /* ̾Ƚʸ(Ѹ) */
+        $ret = check_str($data["subjectencryptstringen"], "[]{}()@!#$%&+*=-/:;.,?_", 0, 256);
+        if (!$ret) {
+            $err_msg = "̾Ƚʸ(Ѹ)ηǤ(". $data["subjectencryptstringen"]. ")";
+            return FALSE;
+        }
+    }
+
+    /* źեեContent-Type */
+    if ($data["zipattachmentcontenttype"] !== "") {
+        /* å */
+        if (check_content_type($data["zipattachmentcontenttype"]) !== TRUE) {
+            $err_msg = "źեեContent-Type" . $err_msg;
+            return FALSE;
+        }
+    }
+
+    return TRUE;
+}
+
+/*********************************************************
+ * check_messagetmplpath
+ *
+ * ʸɵΥեѥͤå
+ * ե¸ߤʤ硢ե
+ * 
+ * []
+ *       $jp_path       ʸɵΥեѥ(ܸ)
+ *       $en_path       ʸɵΥեѥ(Ѹ)
+ *       $both_path     ʸɵΥեѥ(ξ)
+ *       &$errormsg     顼å(ȥǡ)
+ *
+ * [֤]
+ *      TRUE            
+ *      FALSE           ۾
+ **********************************************************/
+function check_messagetmplpath($jp_path, $en_path, $both_path, &$errormsg)
+{
+    if (strlen($jp_path) > 256) {
+        $errormsg = "ʸɵΥեѥ(ܸ)ĹǤ($jp_path)";
+        return FALSE;
+    }
+
+    if (strlen($en_path) > 256) {
+        $errormsg = "ʸɵΥեѥ(Ѹ)ĹǤ($en_path)";
+        return FALSE;
+    }
+
+    if (strlen($both_path) > 256) {
+        $errormsg = "ʸɵΥեѥ(ξ)ĹǤ($both_path)";
+        return FALSE;
+    }
+
+    if ($jp_path !== "") {
+        /* ե¸ߤå */
+        if (!file_exists($jp_path)) {
+            /* ե */
+            if (touch($jp_path) === FALSE) { 
+                $errormsg = "ʸɵΥե(ܸ)κ˼Ԥޤ($jp_path)";
+                return FALSE;
+            }
+        }
+       /* ̾ե뤫ɤĴ٤ */
+       if(!is_file($jp_path)) {
+            $errormsg = "ʸɵΥե(ܸ)̾եǤϤޤ($jp_path)";
+            return FALSE;
+       }
+    }
+
+    if ($en_path !== "") {
+        /* ե¸ߤå */
+        if (!file_exists($en_path)) {
+            /* ե */
+            if (!touch($en_path)) {
+                $errormsg = "ʸɵΥե(Ѹ)κ˼Ԥޤ($en_path)";
+                return FALSE;
+            }
+        }
+       /* ̾ե뤫ɤĴ٤ */
+       if(!is_file($en_path)) {
+            $errormsg = "ʸɵΥե(ܸ)̾եǤϤޤ($en_path)";
+            return FALSE;
+       }
+    }
+
+    if ($both_path) {
+        /* ե¸ߤå */
+        if (!file_exists($both_path)) {
+            /* ե */
+            if (!touch($both_path)) {
+                $errormsg = "ʸɵΥե(ξ)κ˼Ԥޤ($both_path)";
+                return FALSE;
+            }
+        }
+        /* ̾ե뤫ɤĴ٤ */
+        if(!is_file($both_path)) {
+            $errormsg = "ʸɵΥե(ܸ)̾եǤϤޤ($both_path)";
+            return FALSE;
+        }
+    }
+
+    return TRUE;
 }
 
 /*********************************************************
@@ -685,12 +958,13 @@ function check_db($db_file, $db_type)
  *
  * []
  *       $filename	ƥץ졼ȥե
+ *       $df_tmpl	ǥեȥƥץ졼ȥե
  *
  * [֤]
  *	TRUE		
  *	FALSE		۾
  **********************************************************/
-function check_tmpl($filename)
+function check_tmpl($filename, $df_tmpl)
 {
     global $err_msg;
 
@@ -708,7 +982,7 @@ function check_tmpl($filename)
         }
 
         /* ƥץ졼ȥե */
-        $ret = make_def_tmpl($filename);
+        $ret = make_def_tmpl($filename, $df_tmpl);
         if ($ret === FALSE) {
             return FALSE;
         }
@@ -783,6 +1057,11 @@ function set_disp_data($data, &$disp_data)
         $disp_data["templatepath"] = $data["templatepath"];
     }
 
+    /* rcpttemplatepath */
+    if (isset($data["rcpttemplatepath"]) === TRUE) {
+        $disp_data["rcpttemplatepath"] = $data["rcpttemplatepath"];
+    }
+
     /* sendmailcommand */
     if (isset($data["sendmailcommand"]) === TRUE) {
         $disp_data["sendmailcommand"] = $data["sendmailcommand"];
@@ -863,6 +1142,57 @@ function set_disp_data($data, &$disp_data)
         }
     }
 
+    /* ˥ѥɤΤ뵡ǽͭˤʤäƤ */
+    if (is_active_plugin("pluginpassnoticeactive")) {
+        /* passwordnotice */
+        if (isset($data["passwordnotice"])) {
+             $disp_data["passwordnotice"] = $data["passwordnotice"];
+        }
+    }
+
+    /* subjectswǽͭˤʤäƤ */
+    if (is_active_plugin("pluginsubjectswactive")) {
+        /* useaddmessageheader */
+        if (isset($data["useaddmessageheader"])) {
+            $disp_data["useaddmessageheader"] = $data["useaddmessageheader"];
+        }
+
+        /* messagetmpljppath */
+        if (isset($data["messagetmpljppath"])) {
+            $disp_data["messagetmpljppath"] = $data["messagetmpljppath"];
+        }
+
+        /* messagetmplenpath */
+        if (isset($data["messagetmplenpath"])) {
+            $disp_data["messagetmplenpath"] = $data["messagetmplenpath"];
+        }
+
+        /* messagetmplbothpath */
+        if (isset($data["messagetmplbothpath"])) {
+            $disp_data["messagetmplbothpath"] = $data["messagetmplbothpath"];
+        }
+  
+        /* useencryptsubject */
+        if (isset($data["useencryptsubject"])) {
+            $disp_data["useencryptsubject"] = $data["useencryptsubject"];
+        }
+
+        /* subjectencryptstringjp */
+        if (isset($data["subjectencryptstringjp"])) {
+            $disp_data["subjectencryptstringjp"] = $data["subjectencryptstringjp"];
+        }
+
+        /* subjectencryptstringen */
+        if (isset($data["subjectencryptstringen"])) {
+            $disp_data["subjectencryptstringen"] = $data["subjectencryptstringen"];
+        }
+    }
+
+    /* źեեContent-Type */
+    if (isset($data["zipattachmentcontenttype"]) === TRUE) {
+        $disp_data["zipattachmentcontenttype"] = $data["zipattachmentcontenttype"];
+    }
+
     return;
 
 }
@@ -873,18 +1203,19 @@ function set_disp_data($data, &$disp_data)
  *
  * []
  *       $filename      ե̾
+ *       $def_tmpl       ǥեȥƥץ졼ȥե
  *
  * [֤]
  *      TRUE            
  *      FALSE           
  **********************************************************/
-function make_def_tmpl($filename)
+function make_def_tmpl($filename, $def_tmpl)
 {
     global $err_msg;
     global $basedir;
 
     /* ǥեȤΥƥץ졼ȥեѥ */
-    $def_tmpl = $basedir .  ETCDIR . DEF_TMPL;
+    $def_tmpl = $basedir .  ETCDIR . $def_tmpl;
 
     /* ǥեȤΥƥץ졼ȥեå */
     if (is_readable_file($def_tmpl) === FALSE) {
@@ -901,6 +1232,31 @@ function make_def_tmpl($filename)
 
 }
 
+/*********************************************************
+ * is_active_plugin
+ *
+ * ץͭƤ뤫å
+ *
+ * []
+ *       $item          
+ *
+ * [֤]
+ *      TRUE            ͭ
+ *      FALSE           ̵
+ **********************************************************/
+function is_active_plugin($item)
+{
+    global $web_conf;
+
+    if (isset($web_conf["postldapadmin"][$item])) {
+        if ($web_conf["postldapadmin"][$item] === "yes") {
+            return TRUE;
+        }
+    }
+
+    return FALSE;
+}
+
 /***********************************************************
  * 
  **********************************************************/
