@@ -237,7 +237,7 @@ if (isset($_POST["delete"]) === TRUE) {
 /* ɲ */
 if (isset($_POST["add"]) === TRUE) {
     /* ͼ */
-    $add_data["domain"] = $_POST["adddomain"];
+    $add_data["domain"] = strtolower($_POST["adddomain"]);
     $add_data["password"] = $_POST["password"];
     $add_data["rule"] = $_POST["rule"];
     $add_data["indivipass"] = $_POST["indivipass"];
