@@ -88,7 +88,7 @@ function print_result(&$looptag)
         }
 
         /*  */
-        $domain = htmlspecialchars($domain);
+        $domain = escape_html($domain);
         $cnv_key = str_replace("'", "\'", $key);
 
         $looptag[$domain_count]["<<KEY>>"] = $key;
@@ -157,7 +157,7 @@ if (isset($samma_conf["senderdb"]) === TRUE) {
 if (isset($_POST["new_add"]) === TRUE) {
 
     /* ɥᥤɲò̤ */
-    dgp_location("add.php", $del_list);
+    dgp_location("add.php");
     exit (0);
 
 /* ܥ󤬲줿Ȥ */
